-- A generic slider class

Slider = Core.class( Sprite )

function Slider:init( bar, dot )
	self.bar = bar
	self.width = self.bar:getWidth()
	self:addChild( self.bar )
	
	self.dot = dot
	self:addChild( self.dot )
	
	self.value = 0
	
	self.isFocus = false
	
	self:addEventListener( Event.MOUSE_DOWN, self.onMouseDown, self )
	self:addEventListener( Event.MOUSE_MOVE, self.onMouseMove, self )
	self:addEventListener( Event.MOUSE_UP, self.onMouseUp, self )
end

function Slider:onMouseDown( event )
	if self.dot:hitTestPoint( event.x, event.y ) then
		self.isFocus = true
		self.x0 = event.x
		
		event:stopPropagation()
	end
end

function Slider:onMouseMove( event )	
	if self.isFocus then
		local dx = event.x - self.x0
		self.dot:setX( self.dot:getX() + dx )
		self.x0 = event.x
		
		-- keep the dot position within its range
		if self.dot:getX() < 0 then self.dot:setX(0) end
		if self.dot:getX() > self.width then self.dot:setX(self.width) end
		self.value = math.floor( 100 * self.dot:getX() / self.width )
			
		event:stopPropagation()
	end
end

function Slider:onMouseUp( event )
	if self.isFocus then
		self.isFocus = false
		
		event:stopPropagation()
	end
end

function Slider:setValue( value )
	local value = math.floor( value )
	-- check within a range of [0, 100]
	if value < 0 then value = 0 end
	if value > 100 then value = 100 end
	posX = self.width * value / 100
	self.dot:setPosition( posX, 0 )
	self.value = value
end

function Slider:getValue()
	return self.value
end
