-- Hilbert Curve Plotting

local points 			-- to be genrated for Hilbert Curve
local plots = {}		-- the storage
local width = application:getDeviceWidth()
local segment = 1		-- to be determined by a function of depth
local timer

function addPlot( first, last )
	local plot = Shape.new()
	plot:setFillStyle( Shape.NONE )
	plot:setLineStyle( 3, 0x000000 )
	plot:beginPath( Shape.NON_ZERO )

	local p = points[first]		-- the first point
	if p ~= nil and points[first + 1] ~= nil then
		plot:moveTo( p.x, p.y )

		for i = first + 1, last do
			p = points[i]
			if p ~= nil then		-- any more left?
				plot:lineTo( p.x, p.y )
			end 
		end

		plot:endPath()
		stage:addChild( plot )
		
		plots[#plots + 1] = plot
	end
end

local start = 1			-- the first point of the first plot

function onTimer( e )
	addPlot( start, start + segment )
	start = start + segment	-- for the next plot			-- 
end

function onTimerComplete( e )
	--timer:stop()
end 

function startPlotting( depth, speed )
	segment = math.pow( 2, depth - 1 )  	-- number of legs per plot
	local duration = 1000 / speed
	local nplots = 4 * segment
	timer = Timer.new( duration, nplots ) 

	timer:addEventListener( Event.TIMER, onTimer )
	timer:addEventListener( Event.TIMER_COMPLETE, onTimerComplete )
	
	points = createHilbertCurve( width, depth )
	
	start = 1
	timer:start()
end 

function clearPlotting()
	for i = 1, #plots do
		stage:removeChild( plots[i] )
	end
	plots = {}
	if timer ~=nil then timer:stop() end
end
